@@ -8,12 +8,12 @@ Created on May 4 2020
 import csv
 from tarfile import open as tf_open
 from argparse import ArgumentParser
-from requests import get as r_get
 from tempfile import NamedTemporaryFile
 from shutil import copyfile
 from os import path as os_path
 from os import makedirs
 from os.path import dirname
+from brs_utils import download_and_extract_gz
 # from .infos import __version__, __readme__
 
 def build_args_parser():
@@ -53,7 +53,7 @@ class Parser:
                                           'retrorules_rr02_rp2_hs',
                                           'retrorules_rr02_rp2_flat_'+rule_type+'.csv')
                 if not os_path.exists(rules_file):
-                    _download(self._retrorules_url, self._rules_path)
+                    download_and_extract_gz(self._retrorules_url, self._rules_path)
             else:
                 raise ValueError(
                         "at least one of --rules_file or --rule_type required")
@@ -182,15 +182,6 @@ def _parseCSV_and_write(infile, rule_type, diameters, outfile):
                         'Cannot convert diameter to integer: '+str(row[4]))
 
 
-def _download(url, path):
-    makedirs(path, exist_ok=True)
-    r = r_get(url)
-    with NamedTemporaryFile() as tempf:
-        tempf.write(r.content)
-        tar = tf_open(tempf.name, mode="r:gz")
-        tar.extractall(path)
-        tar.close()
-
 
 def _add_arguments(parser):
     parser.add_argument('-rf', '--rules-file',
